@@ -5,6 +5,7 @@ use super::*;
 const CAPACITY: usize = 1024;
 
 /// Sized pool object with a max capacity of 1024 items.
+#[derive(Copy, Clone)]
 pub struct SizedPool1024<ItemType> { 
     items: [Option<ItemType>; CAPACITY], 
     order: [usize; CAPACITY], 
@@ -78,6 +79,14 @@ where ItemType: Copy + PartialEq
     }
 }
 
+impl<ItemType> Default for SizedPool1024<ItemType> 
+where ItemType: Copy + PartialEq
+{
+    fn default() -> Self {
+        SizedPool1024::<ItemType>::new()
+    }
+}
+
 impl<ItemType> StackPool<ItemType> for SizedPool1024<ItemType> {
     fn count(&self) -> &usize { 
         &self.count 
